import { http } from '@/utils/http';

export interface CabinetCellQuery extends BasePageQuery {
  cabinetId?: number;
  cellNo?: number;
  cellType?: number;
}

export interface CabinetCellDTO {
  cellId?: number;
  cabinetId: number;
  cellNo: number;
  pinNo: number;
  cellType: number;
  usageStatus: number;
  availableStatus: number;
  operator?: string;
}

export interface AddCabinetCellCommand {
  cabinetId: number;
  cellNo: number;
  pinNo: number;
  cellType: number;
  usageStatus: number;
  availableStatus: number;
}

export interface UpdateCabinetCellCommand extends AddCabinetCellCommand {
  usageStatus: number;
  availableStatus: number;
}

export const getCabinetCellList = (params?: CabinetCellQuery) => {
  return http.request<ResponseData<PageDTO<CabinetCellDTO>>>('get', '/cabinet/cell', {
    params
  });
};

export const addCabinetCell = (data: AddCabinetCellCommand) => {
  return http.request<ResponseData<void>>('post', '/cabinet/cell', {
    data
  });
};

export const updateCabinetCell = (cellId: number, data: UpdateCabinetCellCommand) => {
  return http.request<ResponseData<void>>('put', `/cabinet/cell/${cellId}`, {
    data
  });
};

export const deleteCabinetCell = (ids: string) => {
  return http.request<ResponseData<void>>('delete', `/cabinet/cell/${ids}`);
};

export interface ConfigureGoodsCellsCommand {
  goodsId: number;
  cellId: number;
}

export const configureGoodsCells = (cellId: number, goodsId: number) => {
  return http.request<ResponseData<void>>('put', `/cabinet/cell/configureGoodsCells/${cellId}/${goodsId}`);
};